@@ -4,7 +4,7 @@
 #include "spvm_compiler.h"
 
 SPVM_USE* SPVM_USE_new(SPVM_COMPILER* compiler) {
-  SPVM_USE* use = SPVM_ALLOCATOR_new_block_compile_tmp(compiler->allocator, sizeof(SPVM_USE));
+  SPVM_USE* use = SPVM_ALLOCATOR_alloc_memory_block_tmp(compiler->allocator, sizeof(SPVM_USE));
   
   return use;
 }
